@@ -6,7 +6,9 @@ library(knitr)
 opts_chunk$set(tidy=FALSE)
 
 ## ----loadChip--------------------------------------------------------------
-library(hgu95av2.db)
+suppressPackageStartupMessages({
+    library(hgu95av2.db)
+})
 
 ## ----listContents----------------------------------------------------------
 ls("package:hgu95av2.db")
@@ -98,7 +100,7 @@ select(edb, keys=keys, columns=c("TXID", "TXSEQSTART", "TXBIOTYPE"),
 ## ----selectEnsDb.Y---------------------------------------------------------
 ## Retrieve all gene IDs of all lincRNAs encoded on chromosome Y
 linkY <- keys(edb,
-              filter=list(GenebiotypeFilter("lincRNA"), SeqnameFilter("Y")))
+              filter=list(GeneBiotypeFilter("lincRNA"), SeqNameFilter("Y")))
 length(linkY)
 
 ## We get now all transcripts for these genes.
@@ -107,7 +109,7 @@ txs <- select(edb, keys=linkY, columns=c("TXID", "TXSEQSTART", "TXBIOTYPE"),
 nrow(txs)
 
 ## Alternatively, we could specify/pass the filters with the keys argument.
-txs <- select(edb, keys=list(GenebiotypeFilter("lincRNA"), SeqnameFilter("Y")),
+txs <- select(edb, keys=list(GeneBiotypeFilter("lincRNA"), SeqNameFilter("Y")),
               columns=c("TXID", "TXSEQSTART", "TXBIOTYPE"))
 nrow(txs)
 
